pub struct ShadowCompared { /* private fields */ }Expand description
Successful comparison of the two effective projections.
Implementations
Sourceimpl ShadowCompared
impl ShadowCompared
Sourcepub const fn verdict(&self) -> ShadowVerdict
pub const fn verdict(&self) -> ShadowVerdict
Return the verdict over covered dimensions.
Sourcepub const fn coverage(&self) -> &ShadowCoverage
pub const fn coverage(&self) -> &ShadowCoverage
Return explicit covered and uncovered dimensions.
Sourcepub fn findings(&self) -> &[ShadowFinding]
pub fn findings(&self) -> &[ShadowFinding]
Return findings in deterministic dimension, label, and value order.
Sourcepub fn is_cutover_evidence(&self) -> bool
pub fn is_cutover_evidence(&self) -> bool
Report whether this comparison alone is sufficient for a V1 cutover.
A partial match is intentionally never cutover evidence.