pub struct FunctionBodyReferences { /* private fields */ }Expand description
Static schema references found in one function body.
Implementations
Sourceimpl FunctionBodyReferences
impl FunctionBodyReferences
Sourcepub const fn references(&self) -> &BTreeSet<SchemaReference>
pub const fn references(&self) -> &BTreeSet<SchemaReference>
Borrow the statically resolved schema identities used by the function body.
Sourcepub const fn has_dynamic_type_reference(&self) -> bool
pub const fn has_dynamic_type_reference(&self) -> bool
Returns true when a type position is supplied by a TypeQL variable.