pub struct TypeqlDeclaredSchema { /* private fields */ }Expand description
A declared schema plus references derived from each TypeQL function body.
The reference index is adapter metadata. It is deliberately excluded from declared-schema canonical bytes and fingerprints.
Implementations
Sourceimpl TypeqlDeclaredSchema
impl TypeqlDeclaredSchema
Sourcepub const fn declared(&self) -> &DeclaredSchema
pub const fn declared(&self) -> &DeclaredSchema
Borrow the canonical declared-schema projection.
Sourcepub fn into_declared(self) -> DeclaredSchema
pub fn into_declared(self) -> DeclaredSchema
Consume the adapter result and return its canonical declared schema.
Sourcepub const fn function_body_references(
&self,
) -> &BTreeMap<FunctionId, FunctionBodyReferences>
pub const fn function_body_references( &self, ) -> &BTreeMap<FunctionId, FunctionBodyReferences>
Borrow references indexed by the function that contains them.